structurefactor (sf)
====================

.. automodule:: jscatter.structurefactor
    :noindex:
   
Structure Factors
-----------------
.. autosummary::
   RMSA
   PercusYevick
   PercusYevick1D
   PercusYevick2D
   stickyHardSphere
   adhesiveHardSphere
   criticalSystem
   latticeStructureFactor
   
Hydrodynamics
-------------
.. autosummary::
   hydrodynamicFunct
   
Pair Correlation
----------------
.. autosummary::
   sq2gr

Lattice
-------
Explicit creating of particle lattice.

.. autosummary::
    bravaisLattice
    scLattice
    bccLattice
    fccLattice
    hexLattice
    hcpLattice
    rhombicLattice

.. autosummary::
    rhombicLattice.X
    rhombicLattice.Y
    rhombicLattice.Z
    rhombicLattice.b
    rhombicLattice.filter
    rhombicLattice.centerOfMass
    rhombicLattice.numberOfAtoms
    rhombicLattice.planeSide
    rhombicLattice.move
    rhombicLattice.inSphere
    rhombicLattice.show
    rhombicLattice.limit2Cube

.. include:: ../../lattice.py
    :start-after: ---
    :end-before:  END

--------

.. automodule:: jscatter.structurefactor
    :members:
    :undoc-members:
    :show-inheritance:
   
.. autoclass:: rhombicLattice
    :members:

.. autoclass:: rhombicLattice
.. autoclass:: bravaisLattice
.. autoclass:: scLattice
.. autoclass:: bccLattice
.. autoclass:: fccLattice
.. autoclass:: hexLattice
.. autoclass:: hcpLattice


